Skip to contents

Create a Quarto presentation, Bioinfo-group styled

Usage

create_bioinfo_revealjs(
  file_name = NULL,
  presentation_folder = NULL,
  ext_name = "bioinfo-revealjs",
  expose_aux_files = TRUE
)

Arguments

file_name

Character string, the name of the file for the report - no need to specify the qmd extension. If preparing a presentation that will end up getting published online, it might be clever to rename the rendered file into index.html (or start already having an index.qmd file, but in the end it is a good practice to keep informative file names)

presentation_folder

Character string, pointing to the folder where the presentation and its associated files should be created. Defaults to NULL, which falls back to the current working directory.

ext_name

Character string, defaulting to "bioinfo-revealjs". Other values (possibly in other functions) would be "bioinfo-html" or similar...

expose_aux_files

Logical value, whether to expose&copy the auxiliary files (scss, and possibly a .bib file as well) into the toplevel of the specified folder.

Value

Invisibly, the path to the created quarto source file for the presentation

See also

Other quartodocuments: create_bioinfo_html()

Examples

temp_folder <- tempdir()
create_bioinfo_revealjs(file_name = "mypresentation",
                        presentation_folder = temp_folder)
#>  Using presentation folder, /var/folders/l7/zzmm12b945z_f71ljwfqj7z00000gn/T//RtmpxTdGib
#>  bioinfo-revealjs was installed to _extensions folder in the specified report directory.
#>  Copied auxiliary files into the toplevel presentation folder.
#> You might want to edit the corresponding lines in the yaml section
#>  Edit
#>   /var/folders/l7/zzmm12b945z_f71ljwfqj7z00000gn/T/RtmpxTdGib/mypresentation.qmd.
#>  Have fun with your presentation - available inside the folder /var/folders/l7/zzmm12b945z_f71ljwfqj7z00000gn/T//RtmpxTdGib